@@ -1,7 +1,7 @@
 /*
  *  R : A Computer Language for Statistical Data Analysis
  *  Copyright (C) 1995, 1996, 1997  Robert Gentleman and Ross Ihaka
- *  Copyright (C) 1998--1998  Robert Gentleman, Ross Ihaka and the R core team
+ *  Copyright (C) 1998--1999 R Development Core Team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -19,6 +19,7 @@
  */
 
 #include "Mathlib.h"/* for imax2(.),..*/
+/*WHEN FIXED: #include "Applic.h" */
 
 /*  Fast Fourier Transform
  *
@@ -27,7 +28,7 @@
  *
  *  I have translated them to C and moved the memory allocation
  *  so that it takes place under the control of the algorithm
- *  which calls these.
+ *  which calls these; for R, see ../main/fourier.c
  *
  *  void fft_factor(int n, int *maxf, int *maxp)
  *
@@ -37,10 +38,14 @@
  *
  *	If maxf is zero on return, an error occured during factorization.
  *	The nature of the error can be determined from the value of maxp.
- *	If maxp is zero, an invalid (zero) parameter was passed and if
- *	maxp is one the internal nfac array was too small.  This can only
+ *	If maxp is zero, an invalid (zero) parameter was passed and
+ *	if maxp is one,	 the internal nfac array was too small.	 This can only
  *	happen for series lengths which exceed 12,754,584.
  *
+ * PROBLEM (see fftmx  below):	nfac[] is overwritten by fftmx() in fft_work()
+ * -------  Consequence:  fft_factor() must be called way too often,
+ * at least from  do_mvfft() [ ../main/fourier.c ]
+ *
  *	The following arrays need to be allocated following the call to
  *	fft_factor and preceding the call to fft_work.
  *
@@ -51,60 +56,60 @@
  *		 int isn, double *work, int *iwork)
  *
  *	The routine returns 1 if the transform was completed successfully and
- *	0 if invalid values of the parameters were supplied.
+ *			    0 if invalid values of the parameters were supplied.
  *
  *  Ross Ihaka
  *  University of Auckland
  *  February 1997
- *
+ *  ==========================================================================
  *
  *  Header from the original Singleton algorithm:
  *
- *  ----------------------------------------------------------------------
- *  subroutine:	 fft
- *  multivariate complex fourier transform, computed in place
- *  using mixed-radix fast fourier transform algorithm.
- *  ----------------------------------------------------------------------
+ * --------------------------------------------------------------
+ * subroutine:	 fft
+ * multivariate complex fourier transform, computed in place
+ * using mixed-radix fast fourier transform algorithm.
+ * --------------------------------------------------------------
  *
- *  arrays a and b originally hold the real and imaginary
- *	 components of the data, and return the real and
- *	 imaginary components of the resulting fourier coefficients.
- *  multivariate data is indexed according to the fortran
- *	 array element successor function, without limit
- *	 on the number of implied multiple subscripts.
- *	 the subroutine is called once for each variate.
- *	 the calls for a multivariate transform may be in any order.
+ * arrays a and b originally hold the real and imaginary
+ *	components of the data, and return the real and
+ *	imaginary components of the resulting fourier coefficients.
+ * multivariate data is indexed according to the fortran
+ *	array element successor function, without limit
+ *	on the number of implied multiple subscripts.
+ *	the subroutine is called once for each variate.
+ *	the calls for a multivariate transform may be in any order.
  *
- *  n is the dimension of the current variable.
- *  nspn is the spacing of consecutive data values
- *	 while indexing the current variable.
- *  nseg*n*nspn is the total number of complex data values.
- *  the sign of isn determines the sign of the complex
- *	 exponential, and the magnitude of isn is normally one.
- *	 the magnitude of isn determines the indexing increment for a&b.
+ * n	is the dimension of the current variable.
+ * nspn is the spacing of consecutive data values
+ *	while indexing the current variable.
+ * nseg nseg*n*nspn is the total number of complex data values.
+ * isn	the sign of isn determines the sign of the complex
+ *	exponential, and the magnitude of isn is normally one.
+ *	the magnitude of isn determines the indexing increment for a&b.
  *
- *  if fft is called twice, with opposite signs on isn, an
- *	 identity transformation is done...calls can be in either order.
- *	 the results are scaled by 1/n when the sign of isn is positive.
+ * if fft is called twice, with opposite signs on isn, an
+ *	identity transformation is done...calls can be in either order.
+ *	the results are scaled by 1/n when the sign of isn is positive.
  *
- *  a tri-variate transform with a(n1,n2,n3), b(n1,n2,n3)
- *  is computed by
- *	   call fft(a,b,n2*n3,n1,1,-1)
- *	   call fft(a,b,n3,n2,n1,-1)
- *	   call fft(a,b,1,n3,n1*n2,-1)
+ * a tri-variate transform with a(n1,n2,n3), b(n1,n2,n3)
+ * is computed by
+ *	call fft(a,b,n2*n3,n1, 1,   -1)
+ *	call fft(a,b,n3	  ,n2,n1,   -1)
+ *	call fft(a,b,1,	   n3,n1*n2,-1)
  *
- *  a single-variate transform of n complex data values is computed by
- *	   call fft(a,b,1,n,1,-1)
+ * a single-variate transform of n complex data values is computed by
+ *	call fft(a,b,1,n,1,-1)
  *
- *  the data may alternatively be stored in a single complex
- *	 array a, then the magnitude of isn changed to two to
- *	 give the correct indexing increment and a(2) used to
- *	 pass the initial address for the sequence of imaginary
- *	 values, e.g.
+ * the data may alternatively be stored in a single complex
+ *	array a, then the magnitude of isn changed to two to
+ *	give the correct indexing increment and a(2) used to
+ *	pass the initial address for the sequence of imaginary
+ *	values, e.g.
  *	   call fft(a,a(2),nseg,n,nspn,-2)
  *
- *  array nfac is working storage for factoring n.  the smallest
- *	 number exceeding the 15 locations provided is 12,754,584.
+ * nfac[15] (array) is working storage for factoring n.	 the smallest
+ *	number exceeding the 15 locations provided is 12,754,584.
  *
  */
 
@@ -140,48 +145,42 @@ void fft_factor(int n, int *pmaxf, int *pmaxp)
 	/* check series length */
 
     if (n <= 0) {
-	old_n = 0;
-	*pmaxf = 0;
-	*pmaxp = 0;
-	return;
+	old_n = 0; *pmaxf = 0; *pmaxp = 0; return;
     }
     else old_n = n;
 
 	/* determine the factors of n */
 
     m = 0;
-    k = n;
+    k = n;/* k := remaining unfactored factor of n */
     if (k == 1) return;
 
-	/* extract square factors first */
+	/* extract square factors first ------------------ */
 
+    /* extract 4^2 = 16 separately 
+     * ==> at most one remaining factor 2^2 = 4, done below */
     while(k % 16 == 0) {
 	nfac[m++] = 4;
-	k = k/16;
+	k /= 16;
     }
 
-    j = 3;
-    jj = 9;
-
-    while(jj <= k) {
+    /* extract 3^2, 5^2, ... */
+    for(j = 3; (jj= j*j) <= k; j += 2) {
 	while(k % jj == 0) {
 	    nfac[m++] = j;
-	    k = k/jj;
+	    k /= jj;
 	}
-	j = j+2;
-	jj = j*j;
     }
 
     if(k <= 4) {
 	kt = m;
 	nfac[m] = k;
-	if(k != 1)
-	    m = m+1;
+	if(k != 1) m++;
     }
     else {
 	if(k % 4 == 0) {
 	    nfac[m++] = 2;
-	    k = k/4;
+	    k /= 4;
 	}
 
 	/* all square factors out now, but k >= 5 still */
@@ -192,9 +191,9 @@ void fft_factor(int n, int *pmaxf, int *pmaxp)
 	do {
 	    if (k % j == 0) {
 		nfac[m++] = j;
-		k = k/j;
+		k /= j;
 	    }
-	    j = ((j+1)/2)*2+1;
+	    j = ((j+1)/2)*2 + 1;
 	}
 	while(j <= k);
     }
@@ -202,10 +201,7 @@ void fft_factor(int n, int *pmaxf, int *pmaxp)
     if (m <= kt+1)
 	maxp = m+kt+1;
     if (m+kt > 15) {		/* error - too many factors */
-	old_n = 0;
-	*pmaxf = 0;
-	*pmaxp = 0;
-	return;
+	old_n = 0; *pmaxf = 0; *pmaxp = 0; return;
     }
     else {
 	if (kt != 0) {
@@ -213,19 +209,25 @@ void fft_factor(int n, int *pmaxf, int *pmaxp)
 	    while(j != 0)
 		nfac[m++] = nfac[--j];
 	}
-	maxf = m-kt;
-	maxf = nfac[maxf-1];
+	maxf = nfac[m-kt-1];
 	if (kt > 0)
 	    maxf = imax2(nfac[kt-1], maxf);
     }
     *pmaxf = maxf;
     *pmaxp = maxp;
 }
-
+
 static void fftmx(double *a, double *b, int ntot, int n, int nspan, int isn,
 		  int m, int kt, double *at, double *ck, double *bt, double *sk,
 		  int *np, int *nfac)
 {
+/* called from  fft_work() */
+
+/* Design BUG:	One purpose of fft_factor() would be to compute
+ * ----------	nfac[] once and for all; and fft_work() [i.e. fftmx ]
+ *		could reuse the factorization.
+ * However: nfac[] is `destroyed' currently in the code below  
+ */
     double aa, aj, ajm, ajp, ak, akm, akp;
     double bb, bj, bjm, bjp, bk, bkm, bkp;
     double c1, c2=0, c3=0, c72, cd;
@@ -236,13 +238,14 @@ static void fftmx(double *a, double *b, int ntot, int n, int nspan, int isn,
     int lim, maxf, mm, nn, nt;
 
     a--; b--; at--; ck--; bt--; sk--;
-    np--; nfac--;
+    np--; 
+    nfac--;/*the global one!*/
 
     inc = abs(isn);
     nt = inc*ntot;
     ks = inc*nspan;
-    rad = atan(1.0);
-    s72 = rad/0.625;
+    rad = M_PI_4;/* = pi/4 =^= 45 degrees */
+    s72 = rad/0.625;/* 72 = 45 / .625  degrees */
     c72 = cos(s72);
     s72 = sin(s72);
     s120 = sqrt(0.75);
@@ -255,8 +258,8 @@ static void fftmx(double *a, double *b, int ntot, int n, int nspan, int isn,
 	/* scale by 1/n for isn > 0 */
 	ak = 1.0/n;
 	for(j=1 ; j<=nt ; j+=inc) {
-	    a[j] = a[j]*ak;
-	    b[j] = b[j]*ak;
+	    a[j] *= ak;
+	    b[j] *= ak;
 	}
 #endif
     }
@@ -271,50 +274,51 @@ static void fftmx(double *a, double *b, int ntot, int n, int nspan, int isn,
     klim = lim*jc;
     i = 0;
     jf = 0;
-    maxf = m - kt;
-    maxf = nfac[maxf];
-    if( kt > 0) maxf = imax2(nfac[kt],maxf);
+    maxf = nfac[m - kt];
+    if(kt > 0) maxf = imax2(nfac[kt],maxf);
 
 	/* compute fourier transform */
 
-L40:
+L_start:
     dr = (8.0*jc)/kspan;
     cd = sin(0.5*dr*rad);
     cd = 2.0*cd*cd;
     sd = sin(dr*rad);
     kk = 1;
-    i = i + 1;
+    i++;
     if( nfac[i] != 2) goto L110;
 
 /* transform for factor of 2 (including rotation factor) */
 
-    kspan = kspan/2;
+    kspan /= 2;
     k1 = kspan + 2;
-L50:
-    k2 = kk + kspan;
-    ak = a[k2];
-    bk = b[k2];
-    a[k2] = a[kk] - ak;
-    b[k2] = b[kk] - bk;
-    a[kk] = a[kk] + ak;
-    b[kk] = b[kk] + bk;
-    kk = k2 + kspan;
-    if( kk <= nn) goto L50;
-    kk = kk - nn;
-    if( kk <= jc) goto L50;
-    if( kk > kspan) goto L_fin;
+    do {
+	do {
+	    k2 = kk + kspan;
+	    ak = a[k2];
+	    bk = b[k2];
+	    a[k2] = a[kk] - ak;
+	    b[k2] = b[kk] - bk;
+	    a[kk] += ak;
+	    b[kk] += bk;
+	    kk = k2 + kspan;
+	} while(kk <= nn);
+	kk -= nn;
+    } while(kk <= jc);
+
+    if(kk > kspan) goto L_fin;
 L60:
     c1 = 1.0 - cd;
     s1 = sd;
     mm = imin2(k1/2,klim);
     goto L80;
+
 L70:
     ak = c1 - (cd*c1+sd*s1);
     s1 = (sd*c1-cd*s1) + s1;
 
 /* the following three statements compensate for truncation error. */
-/* if rounded arithmetic is used, substitute  c1=ak */
-
+/* if rounded arithmetic is used (nowadays always ?!), substitute  c1=ak */
 #ifdef TRUNCATED_ARITHMETIC
     c1 = 0.5/(ak*ak+s1*s1) + 0.5;
     s1 = c1*s1;
@@ -324,27 +328,29 @@ L70:
 #endif
 
 L80:
-    k2 = kk + kspan;
-    ak = a[kk] - a[k2];
-    bk = b[kk] - b[k2];
-    a[kk] = a[kk] + a[k2];
-    b[kk] = b[kk] + b[k2];
-    a[k2] = c1*ak - s1*bk;
-    b[k2] = s1*ak + c1*bk;
-    kk = k2 + kspan;
-    if( kk < nt) goto L80;
+    do {
+	k2 = kk + kspan;
+	ak = a[kk] - a[k2];
+	bk = b[kk] - b[k2];
+	a[kk] += a[k2];
+	b[kk] += b[k2];
+	a[k2] = c1*ak - s1*bk;
+	b[k2] = s1*ak + c1*bk;
+	kk = k2 + kspan;
+    } while(kk < nt);
     k2 = kk - nt;
     c1 = -c1;
     kk = k1 - k2;
     if( kk > k2) goto L80;
-    kk = kk + jc;
-    if( kk <= mm) goto L70;
-    if( kk < k2) goto L90;
-    k1 = k1 + inc + inc;
-    kk = (k1-kspan)/2 + jc;
-    if( kk <= jc+jc) goto L60;
-    goto L40;
-L90:
+    kk += jc;
+    if(kk <= mm) goto L70;
+    if(kk >= k2) {
+	k1 = k1 + inc + inc;
+	kk = (k1-kspan)/2 + jc;
+	if( kk <= jc+jc) goto L60;
+	goto L_start;
+    }
+
     s1 = ((kk-1)/jc)*dr*rad;
     c1 = cos(s1);
     s1 = sin(s1);
@@ -381,7 +387,7 @@ L100:
 L110:
     if( nfac[i] != 4) goto L_f_odd;
     kspnn = kspan;
-    kspan = kspan/4;
+    kspan /= 4;
 L120:
     c1 = 1.0;
     s1 = 0;
@@ -392,8 +398,7 @@ L130:
     s1 = (sd*c1-cd*s1) + s1;
 
 /* the following three statements compensate for truncation error. */
-/* if rounded arithmetic is used, substitute  c1=c2 */
-
+/* if rounded arithmetic is used (nowadays always ?!), substitute  c1=c2 */
 #ifdef TRUNCATED_ARITHMETIC
     c1 = 0.5/(c2*c2+s1*s1) + 0.5;
     s1 = c1*s1;
@@ -407,6 +412,7 @@ L140:
     s2 = c1*s1*2.0;
     c3 = c2*c1 - s2*s1;
     s3 = c2*s1 + s2*c1;
+
 L150:
     k1 = kk + kspan;
     k2 = k1 + kspan;
@@ -443,9 +449,9 @@ L170:
     if( kk <= mm) goto L130;
     if( kk < kspan) goto L200;
     kk = kk - kspan + inc;
-    if( kk <= jc) goto L120;
-    if( kspan == jc) goto L_fin;
-    goto L40;
+    if(kk <= jc) goto L120;
+    if(kspan == jc) goto L_fin;
+    goto L_start;
 L180:
     akp = akm + bjm;
     akm = akm - bjm;
@@ -518,25 +524,25 @@ L220:
 L_f_odd:
     k = nfac[i];
     kspnn = kspan;
-    kspan = kspan/k;
-    if( k == 3) goto L100;
-    if( k == 5) goto L_f5;
-    if( k == jf) goto L250;
+    kspan /= k;
+    if(k == 3) goto L100;
+    if(k == 5) goto L_f5;
+    if(k == jf) goto L250;
     jf = k;
     s1 = rad/(k/8.0);
     c1 = cos(s1);
     s1 = sin(s1);
     ck[jf] = 1.0;
     sk[jf] = 0.0;
-    j = 1;
-L240:
-    ck[j] = ck[k]*c1 + sk[k]*s1;
-    sk[j] = ck[k]*s1 - sk[k]*c1;
-    k = k - 1;
-    ck[k] = ck[j];
-    sk[k] = -sk[j];
-    j = j + 1;
-    if( j < k) goto L240;
+
+    for(j = 1; j < k; j++) { /* k is changing as well */
+	ck[j] = ck[k]*c1 + sk[k]*s1;
+	sk[j] = ck[k]*s1 - sk[k]*c1;
+	k--;
+	ck[k] = ck[j];
+	sk[k] = -sk[j];
+    }
+
 L250:
     k1 = kk;
     k2 = kk + kspnn;
@@ -548,12 +554,12 @@ L250:
     k1 = k1 + kspan;
 L260:
     k2 = k2 - kspan;
-    j = j + 1;
+    j++;
     at[j] = a[k1] + a[k2];
     ak = at[j] + ak;
     bt[j] = b[k1] + b[k2];
     bk = bt[j] + bk;
-    j = j + 1;
+    j++;
     at[j] = a[k1] - a[k2];
     bt[j] = b[k1] - b[k2];
     k1 = k1 + kspan;
@@ -564,30 +570,29 @@ L260:
     k2 = kk + kspnn;
     j = 1;
 L270:
-    k1 = k1 + kspan;
-    k2 = k2 - kspan;
+    k1 += kspan;
+    k2 -= kspan;
     jj = j;
     ak = aa;
     bk = bb;
     aj = 0.0;
     bj = 0.0;
     k = 1;
-L280:
-    k = k + 1;
-    ak = at[k]*ck[jj] + ak;
-    bk = bt[k]*ck[jj] + bk;
-    k = k + 1;
-    aj = at[k]*sk[jj] + aj;
-    bj = bt[k]*sk[jj] + bj;
-    jj = jj + j;
-    if( jj > jf) jj = jj - jf;
-    if( k < jf) goto L280;
+    for(k=2; k < jf; k++) {
+	ak += at[k]*ck[jj];
+	bk += bt[k]*ck[jj];
+	k++;		  
+	aj += at[k]*sk[jj];
+	bj += bt[k]*sk[jj];
+	jj += j;
+	if(jj > jf) jj -= jf;
+    }
     k = jf - j;
     a[k1] = ak - bj;
     b[k1] = bk + aj;
     a[k2] = ak + bj;
     b[k2] = bk - aj;
-    j = j + 1;
+    j++;
     if( j < k) goto L270;
     kk = kk + kspnn;
     if( kk <= nn) goto L250;
@@ -597,53 +602,52 @@ L280:
 /* multiply by rotation factor (except for factors of 2 and 4) */
 
 L290:
-    if( i == m) goto L_fin;
+    if(i == m) goto L_fin;
     kk = jc + 1;
 L300:
     c2 = 1.0 - cd;
     s1 = sd;
     mm = imin2(kspan,klim);
-    goto L320;
-L310:
-    c2 = c1 - (cd*c1+sd*s1);
-    s1 = s1 + (sd*c1-cd*s1);
 
+    do { /* L320: */
+	c1 = c2;
+	s2 = s1;
+	kk += kspan;
+	do { /* L330: */
+	    do {
+		ak = a[kk];
+		a[kk] = c2*ak - s2*b[kk];
+		b[kk] = s2*ak + c2*b[kk];
+		kk += kspnn;
+	    } while(kk <= nt);
+	    ak = s1*s2;
+	    s2 = s1*c2 + c1*s2;
+	    c2 = c1*c2 - ak;
+	    kk += -nt + kspan;
+	} while(kk <= kspnn);
+	kk += -kspnn + jc;
+	if(kk <= mm) { /* L310: */
+	    c2 = c1 - (cd*c1+sd*s1);
+	    s1 = s1 + (sd*c1-cd*s1);
 /* the following three statements compensate for truncation error.*/
-/* if rounded arithmetic is used, they may be deleted. */
-
+/* if rounded arithmetic is used (nowadays always ?!), they may be deleted. */
 #ifdef TRUNCATED_ARITHMETIC
-    c1 = 0.5/(c2*c2+s1*s1) + 0.5;
-    s1 = c1*s1;
-    c2 = c1*c2;
+	    c1 = 0.5/(c2*c2+s1*s1) + 0.5;
+	    s1 = c1*s1;
+	    c2 = c1*c2;
 #endif
-
-L320:
-    c1 = c2;
-    s2 = s1;
-    kk = kk + kspan;
-L330:
-    ak = a[kk];
-    a[kk] = c2*ak - s2*b[kk];
-    b[kk] = s2*ak + c2*b[kk];
-    kk = kk + kspnn;
-    if( kk <= nt) goto L330;
-    ak = s1*s2;
-    s2 = s1*c2 + c1*s2;
-    c2 = c1*c2 - ak;
-    kk = kk - nt + kspan;
-    if( kk <= kspnn) goto L330;
-    kk = kk - kspnn + jc;
-    if( kk <= mm) goto L310;
-    if( kk < kspan) goto L340;
-    kk = kk - kspan + jc + inc;
-    if( kk <= jc+jc) goto L300;
-    goto L40;
-L340:
-    s1 = ((kk-1)/jc)*dr*rad;
-    c2 = cos(s1);
-    s1 = sin(s1);
-    mm = imin2(kspan,mm+klim);
-    goto L320;
+	    continue/* goto L320*/;
+	}
+	if(kk >= kspan) {
+	    kk = kk - kspan + jc + inc;
+	    if( kk <= jc+jc) goto L300;
+	    goto L_start;
+	}
+	s1 = ((kk-1)/jc)*dr*rad;
+	c2 = cos(s1);
+	s1 = sin(s1);
+	mm = imin2(kspan,mm+klim);
+    } while(1);
 
 /*------------------------------------------------------------*/
 
@@ -655,177 +659,159 @@ L_fin:
     np[1] = ks;
     if( kt == 0) goto L440;
     k = kt + kt + 1;
-    if( m < k) k = k - 1;
-    j = 1;
+    if( m < k) k--;
     np[k+1] = jc;
-L360:
-    np[j+1] = np[j]/nfac[j];
-    np[k] = np[k+1]*nfac[j];
-    j = j + 1;
-    k = k - 1;
-    if( j < k) goto L360;
+    for(j = 1; j < k; j++, k--) {
+	np[j+1] = np[j]/nfac[j];
+	np[k] = np[k+1]*nfac[j];
+    }
     k3 = np[k+1];
     kspan = np[2];
     kk = jc + 1;
     k2 = kspan + 1;
     j = 1;
-    if( n != ntot) goto L400;
 
-/* permutation for single-variate transform (optional code) */
+    if(n == ntot) {
 
-L370:
-    ak = a[kk];
-    a[kk] = a[k2];
-    a[k2] = ak;
-    bk = b[kk];
-    b[kk] = b[k2];
-    b[k2] = bk;
-    kk = kk + inc;
-    k2 = kspan + k2;
-    if( k2 < ks) goto L370;
-L380:
-    k2 = k2 - np[j];
-    j = j + 1;
-    k2 = np[j+1] + k2;
-    if( k2 > np[j]) goto L380;
-    j = 1;
-L390:
-    if( kk < k2) goto L370;
-    kk = kk + inc;
-    k2 = kspan + k2;
-    if( k2 < ks) goto L390;
-    if( kk < ks) goto L380;
-    jc = k3;
-    goto L440;
+	/* permutation for single-variate transform (optional code) */
 
-/* permutation for multivariate transform */
+      L370:
+	do {
+	    ak = a[kk];	   a[kk] = a[k2];    a[k2] = ak;
+	    bk = b[kk];	   b[kk] = b[k2];    b[k2] = bk;
+	    kk += inc;
+	    k2 += kspan;
+	} while(k2 < ks);
+      L380:
+	do { k2 -= np[j]; j++; k2 += np[j+1]; } while(k2 > np[j]);
+	j = 1;
+	do {
+	    if(kk < k2) goto L370;
+	    kk += inc;
+	    k2 += kspan;
+	} while(k2 < ks);
+	if( kk < ks) goto L380;
+	jc = k3;
+
+    } else {
+
+	/* permutation for multivariate transform */
+
+      L400:
+	k = kk + jc;
+	do {
+	    ak = a[kk]; a[kk] = a[k2]; a[k2] = ak;
+	    bk = b[kk]; b[kk] = b[k2]; b[k2] = bk;
+	    kk += inc;
+	    k2 += inc;
+	} while( kk < k);
+	kk += ks - jc;
+	k2 += ks - jc;
+	if(kk < nt) goto L400;
+	k2 += - nt + kspan;
+	kk += - nt + jc;
+	if( k2 < ks) goto L400;
+
+	do {
+	    do { k2 -= np[j]; j++; k2 += np[j+1]; } while(k2 > np[j]);
+	    j = 1;
+	    do {
+		if(kk < k2) goto L400;
+		kk += jc;
+		k2 += kspan;
+	    } while(k2 < ks);
+	} while(kk < ks);
+	jc = k3;
+    }
 
-L400:
-    k = kk + jc;
-L410:
-    ak = a[kk];
-    a[kk] = a[k2];
-    a[k2] = ak;
-    bk = b[kk];
-    b[kk] = b[k2];
-    b[k2] = bk;
-    kk = kk + inc;
-    k2 = k2 + inc;
-    if( kk < k) goto L410;
-    kk = kk + ks - jc;
-    k2 = k2 + ks - jc;
-    if( kk < nt) goto L400;
-    k2 = k2 - nt + kspan;
-    kk = kk - nt + jc;
-    if( k2 < ks) goto L400;
-L420:
-    k2 = k2 - np[j];
-    j = j + 1;
-    k2 = np[j+1] + k2;
-    if( k2 > np[j]) goto L420;
-    j = 1;
-L430:
-    if( kk < k2) goto L400;
-    kk = kk + jc;
-    k2 = kspan + k2;
-    if( k2 < ks) goto L430;
-    if( kk < ks) goto L420;
-    jc = k3;
 L440:
     if( 2*kt+1 >= m) return;
     kspnn = np[kt+1];
 
 /* permutation for square-free factors of n */
 
-    j = m - kt;
-    nfac[j+1] = 1;
-L450:
-    nfac[j] = nfac[j]*nfac[j+1];
-    j = j - 1;
-    if( j != kt) goto L450;
-    kt = kt + 1;
+    /* Here, nfac[] is overwritten... -- now CUMULATIVE ("cumprod") factors */
+    nn = m - kt;
+    nfac[nn+1] = 1;
+    for(j = nn; j > kt; j--)
+	nfac[j] *= nfac[j+1];
+    kt++;
     nn = nfac[kt] - 1;
     jj = 0;
     j = 0;
     goto L480;
 L460:
-    jj = jj - k2;
+    jj -= k2;
     k2 = kk;
-    k = k + 1;
+    k++;
     kk = nfac[k];
 L470:
-    jj = kk + jj;
+    jj += kk;
     if( jj >= k2) goto L460;
     np[j] = jj;
 L480:
     k2 = nfac[kt];
     k = kt + 1;
     kk = nfac[k];
-    j = j + 1;
+    j++;
     if( j <= nn) goto L470;
 
 /* determine the permutation cycles of length greater than 1 */
 
     j = 0;
     goto L500;
-L490:
-    k = kk;
-    kk = np[k];
-    np[k] = -kk;
-    if( kk != j) goto L490;
-    k3 = kk;
-L500:
-    j = j + 1;
-    kk = np[j];
-    if( kk < 0) goto L500;
-    if( kk != j) goto L490;
+
+    do {
+	do { k = kk; kk = np[k]; np[k] = -kk; } while(kk != j);
+	k3 = kk;
+      L500:
+	do { j++; kk = np[j]; } while(kk < 0);
+    } while(kk != j);
     np[j] = -j;
     if( j != nn) goto L500;
-    maxf = inc*maxf;
+    maxf *= inc;
+    goto L570;
 
 /* reorder a and b, following the permutation cycles */
 
-    goto L570;
 L_ord:
-    j = j - 1;
-    if( np[j] < 0) goto L_ord;
+    do j--; while(np[j] < 0);
     jj = jc;
+
 L520:
-    kspan = jj;
-    if( jj > maxf) kspan = maxf;
-    jj = jj - kspan;
+    kspan = imin2(jj,maxf);
+    jj -= kspan;
     k = np[j];
     kk = jc*k + i + jj;
-    k1 = kk + kspan;
-    k2 = 0;
-L530:
-    k2 = k2 + 1;
-    at[k2] = a[k1];
-    bt[k2] = b[k1];
-    k1 = k1 - inc;
-    if( k1 != kk) goto L530;
-L540:
-    k1 = kk + kspan;
-    k2 = k1 - jc*(k+np[k]);
-    k = -np[k];
-L550:
-    a[k1] = a[k2];
-    b[k1] = b[k2];
-    k1 = k1 - inc;
-    k2 = k2 - inc;
-    if( k1 != kk) goto L550;
-    kk = k2;
-    if( k != j) goto L540;
-    k1 = kk + kspan;
-    k2 = 0;
-L560:
-    k2 = k2 + 1;
-    a[k1] = at[k2];
-    b[k1] = bt[k2];
-    k1 = k1 - inc;
-    if( k1 != kk) goto L560;
-    if( jj != 0) goto L520;
+
+    for(k1= kk + kspan, k2= 1; k1 != kk;
+	k1 -= inc, k2++) {
+	at[k2] = a[k1];
+	bt[k2] = b[k1];
+    }
+
+    do {
+	k1 = kk + kspan;
+	k2 = k1 - jc*(k+np[k]);
+	k = -np[k];
+	do {
+	    a[k1] = a[k2];
+	    b[k1] = b[k2];
+	    k1 -= inc;
+	    k2 -= inc;
+	} while( k1 != kk);
+	kk = k2;
+    } while(k != j);
+
+    for(k1= kk + kspan, k2= 1; k1 > kk;
+	k1 -= inc, k2++) {
+	a[k1] = at[k2];
+	b[k1] = bt[k2];
+    }
+
+    if(jj != 0) goto L520;
     if( j != 1) goto L_ord;
+
 L570:
     j = k3 + 1;
     nt = nt - kspnn;
@@ -842,8 +828,7 @@ int fft_work(double *a, double *b, int nseg, int n, int nspn, int isn,
 
     if(old_n == 0) return 0;
 
-	/* check that the parameters match those */
-	/* of the factorization call */
+	/* check that the parameters match those of the factorization call */
 
     if(n != old_n || nseg <= 0 || nspn <= 0 || isn == 0)
 	return 0;
@@ -854,8 +839,9 @@ int fft_work(double *a, double *b, int nseg, int n, int nspn, int isn,
     nspan = nf * nspn;
     ntot = nspan * nseg;
 
-    fftmx(a, b, ntot, nf, nspan, isn, m, kt, &work[0],
-	  &work[maxf], &work[2*maxf], &work[3*maxf], iwork, nfac);
+    fftmx(a, b, ntot, nf, nspan, isn, m, kt, 
+	  &work[0], &work[maxf], &work[2*maxf], &work[3*maxf], 
+	  iwork, nfac);
 
     return 1;
 }
