@@ -193,23 +193,30 @@ static void xbuffixl(xbuf p)
    To be fixed: during creation, memory is allocated two times
    (faster for small files but a big waste otherwise)
 */
-static xbuf file2xbuf(char *name,int del)
+static xbuf file2xbuf(char *name, int del)
 {
     HANDLE f;
     DWORD rr, vv;
-    char *q, *p;
+    char *q, *p, buf[MAX_PATH + 25];
     xlong dim;
     xint  ms;
     xbuf  xb;
 
     f = CreateFile(name, GENERIC_READ, FILE_SHARE_WRITE,
 		   NULL, OPEN_EXISTING, 0, NULL);
-    if (f == INVALID_HANDLE_VALUE)
+    if (f == INVALID_HANDLE_VALUE) {
+	sprintf(buf, "File %s could not be opened by internal pager\n", name);
+	warning(buf);
 	return NULL;
+    }
     vv = GetFileSize(f, NULL);
     p = (char *) winmalloc((size_t) vv + 1);
     if (!p) {
 	CloseHandle(f);
+	sprintf(buf,
+		"Insufficient memory to display %s in internal pager\n",
+		name);
+	warning(buf);
 	return NULL;
     }
     ReadFile(f, p, vv, &rr, NULL);
@@ -219,8 +226,10 @@ static xbuf file2xbuf(char *name,int del)
     for (q = p, ms = 1, dim = rr; *q; q++) {
 	if (*q == '\t')
 	    dim += TABSIZE;
-	else if (*q == '\n')
+	else if (*q == '\n') {
+            dim++;
 	    ms++;
+        }
     }
     if ((xb = newxbuf(dim + 1, ms, 1)))
 	for (q = p; *q; q++)
@@ -256,7 +265,7 @@ struct structConsoleData {
 
     int   cur_pos, max_pos, prompt_len;	/* editing */
     xbuf  history;
-    
+
     char  chbrk, modbrk;	/* hook for user's break */
     void  (*fbrk) ();
 
@@ -631,7 +640,7 @@ FBEGIN
     int i;
     if (p->sel) {
 	p->sel = 0;
-	p->needredraw = 1; 
+	p->needredraw = 1;
 	REDRAW;
     }
     storekey(c, BEGINLINE);
@@ -653,7 +662,7 @@ FBEGIN
     char *pc, *new = NULL;
     if (p->sel) {
 	p->sel = 0;
-	p->needredraw = 1; 
+	p->needredraw = 1;
 	REDRAW;
      }
     if (p->kind == PAGER) FVOIDRETURN;
@@ -665,7 +674,7 @@ FBEGIN
            new = winrealloc((void *)p->clp, strlen(p->clp) + strlen(pc) + 1);
         }
         else {
-           new = winmalloc(strlen(pc) + 1) ;   
+           new = winmalloc(strlen(pc) + 1) ;
            if (new) new[0] = '\0';
            p->already = p->numkeys;
            p->pclp = 0;
@@ -676,7 +685,7 @@ FBEGIN
         }
         else {
            askok("Not enough memory");
-        }   
+        }
         GlobalUnlock(hglb);
     }
     CloseClipboard();
@@ -728,7 +737,7 @@ FBEGIN
     *s = '\0';
     GlobalUnlock(hglb);
     if (!OpenClipboard(NULL) || !EmptyClipboard()) {
-        askok("Impossible to open the clipboard");
+        askok("Unable to open the clipboard");
         GlobalFree(hglb);
         FVOIDRETURN;
     }
@@ -922,7 +931,7 @@ FBEGIN
     }
     if (p->sel) {
 	p->sel = 0;
-	p->needredraw = 1; 
+	p->needredraw = 1;
 	REDRAW;
     }
 FVOIDEND
@@ -973,9 +982,9 @@ static char consolegetc(control c)
     }
     if (p->sel) {
 	p->sel = 0;
-	p->needredraw = 1; 
+	p->needredraw = 1;
 	REDRAW;
-    }    
+    }
     if (!p->already && p->clp)
     {
 	ch = p->clp[p->pclp++];
@@ -1176,7 +1185,7 @@ FBEGIN
     fp = fopen(s, "w");
     if (!fp) {
        char msg[256];
-       sprintf(msg, "Impossible to open %s", s);
+       sprintf(msg, "Unable to open %s", s);
        askok(s);
        FVOIDRETURN;
     }
@@ -1207,7 +1216,7 @@ int setWidthOnResize = 0;
 int consolecols(console c)
 {
     ConsoleData p = getdata(c);
-    
+
     return p->cols;
 }
 
@@ -1233,6 +1242,8 @@ FBEGIN
     HEIGHT = r.height;
     BORDERX = (WIDTH - COLS*FW) / 2;
     BORDERY = (HEIGHT - ROWS*FH) / 2;
+    if(p->lbuf) FVOIDRETURN;    /* don't implement resize if no content
+				   yet in pager */
     del(BM);
     BM = newbitmap(r.width, r.height, 2);
     if (!BM) {
@@ -1289,7 +1300,7 @@ setconsoleoptions(char *fnname,int fnsty, int fnpoints,
        consolefn = FixedFont;
     }
     if (!ghasfixedwidth(consolefn)) {
-       sprintf(msg, 
+       sprintf(msg,
 	       "Font %s-%d-%d has variable width.\nUsing system fixed font.",
                fontname, fontsty, pointsize);
        askok(msg);
@@ -1515,7 +1526,7 @@ static void pagerpaste(control m)
     if (consolecanpaste(RConsole)) {
 	consolepaste(RConsole);
 	show(RConsole);
-    } 
+    }
 }
 
 static void pagerselectall(control m)
@@ -1563,7 +1574,7 @@ static int pageraddfile(char *wtitle, char *filename, int deleteonexit)
     xbuf nxbuf = file2xbuf(filename, deleteonexit);
 
     if (!nxbuf) {
-	askok("File not found or memory insufficient");
+	askok("Pager: file not found or memory insufficient");
 	return 0;
     }
     if (pagerActualKept == PAGERMAXKEPT) {
@@ -1648,7 +1659,7 @@ static pager pagercreate()
     if (!c) {
          freeConsoleData(p);
          return NULL;
-    }         
+    }
     setdata(c, p);
     if(h == 0) HEIGHT = getheight(c);
     if(w == 0) WIDTH  = getwidth(c);
@@ -1684,10 +1695,10 @@ static pager pagercreate()
     addto(c);
     MCHECK(m = gpopup(pagermenuact, PagerPopup));
     setdata(m, c);
-    setdata(p->mpopcopy = PagerPopup[0].m, c); 
-    setdata(p->mpoppaste = PagerPopup[1].m, c); 
-    setdata(PagerPopup[2].m, c); 
-    setdata(PagerPopup[4].m, c); 
+    setdata(p->mpopcopy = PagerPopup[0].m, c);
+    setdata(p->mpoppaste = PagerPopup[1].m, c);
+    setdata(PagerPopup[2].m, c);
+    setdata(PagerPopup[4].m, c);
     MCHECK(m = newmenubar(pagermenuact));
     setdata(m, c);
     MCHECK(newmenu("File"));
@@ -1731,7 +1742,7 @@ static pager pagercreate()
 pager newpager1win(char *wtitle, char *filename, int deleteonexit)
 {
     if (!pagerInstance && !(pagerInstance = pagercreate())) {
-        askok("Impossible to create pager windows");
+        askok("Unable to create pager windows");
         return NULL;
     }
     if (!pageraddfile(wtitle, filename, deleteonexit)) return NULL;
@@ -1760,7 +1771,7 @@ pager newpager(char *title, char *filename, char *header, int deleteonexit)
     char wtitle[PAGERMAXTITLE+1];
     pager c;
 
-    if (ismdi()) pagerMultiple = 1;
+    /*    if (ismdi()) pagerMultiple = 1;*/
     strncpy(wtitle, title, PAGERMAXTITLE);
     wtitle[PAGERMAXTITLE] = '\0';
     if(strlen(header) &&
