@@ -515,17 +515,26 @@ void UnLoad_Unzip_Dll();
 /* Process ~/.Renviron, if it exists */
 #include "opt.h"
 
+/* like putenv, but allocate storage */
+static void Putenv(char *str)
+{
+    char *buf;
+    buf = (char *) malloc((strlen(str) + 1) * sizeof(char));
+    strcpy(buf, str);
+    putenv(buf);
+}
+
 static void processRenviron()
 {
     char *opt[2], optf[MAX_PATH], buf[80];
     int   ok;
 
-    sprintf(optf, "%s/Renviron", getenv("R_HOME"));
+    sprintf(optf, "%s/.Renviron", getenv("R_HOME"));
     if (!optopenfile(optf))
 	return;
     while ((ok = optread(opt, '='))) {
 	sprintf(buf, "%s=%s", opt[0], opt[1]);
-	putenv(buf);
+	Putenv(buf);
     }
     optclosefile();
 }
@@ -1101,6 +1110,22 @@ int R_ShowFiles(int nfile, char **file, char **headers, char *wtitle,
 	for (i = 0; i < nfile; i++) {
 	    if (!strcmp(pager, "internal")) {
 		newpager(wtitle, file[i], headers[i], del);
+            } if (!strcmp(pager, "console")) {
+                DWORD len = 1;
+                HANDLE f = CreateFile(file[i], GENERIC_READ, FILE_SHARE_WRITE,
+		   NULL, OPEN_EXISTING, 0, NULL);
+                if (f != INVALID_HANDLE_VALUE) {
+                  while (ReadFile(f,buf,1023,&len,NULL) && len) {
+                    buf[len] = '\0';
+                    R_WriteConsole(buf,strlen(buf));
+                  }
+                  CloseHandle(f);
+                  if (del) DeleteFile(file[i]);
+                }
+                else {
+                  sprintf(buf,"Impossible to open file '%s'. Does it exist?\n",file[i]);
+                  warning(buf);
+                }
 	    } else {
 		sprintf(buf, "%s  %s", pager, file[i]);
 		runcmd(buf, 0, 1, "");
