@@ -6,7 +6,8 @@ model.tables.aov <- function(x, type = "effects", se = FALSE, cterms)
     if(inherits(x, "maov"))
 	stop("model.tables is not implemented for multiple responses")
     type <- match.arg(type, c("effects", "means", "residuals"))
-    if(type == "residuals") stop(paste("type", type, "not implemented yet"))
+    if(type == "residuals")
+	stop(paste("type", type, "not implemented yet"))
     prjs <- proj(x, unweighted.scale = TRUE)
     mf <- model.frame(x)
     factors <- attr(prjs, "factors")
@@ -80,7 +81,8 @@ se.aov <- function(object, n, type = "means")
 model.tables.aovlist <- function(x, type = "effects", se = FALSE, ...)
 {
     type <- match.arg(type, c("effects", "means", "residuals"))
-    if(type == "residuals") stop(paste("type", type, "not implemented yet"))
+    if(type == "residuals")
+	stop(paste("type", type, "not implemented yet"))
     prjs <- proj(x, unweighted.scale = TRUE)
     mf <- model.frame.aovlist(x)
     factors <- lapply(prjs, attr, "factors")
