@@ -1,13 +1,7 @@
 sapply <- function(X, FUN, ..., simplify = TRUE)
 {
-    if(is.character(FUN))
-	FUN <- get(FUN, mode = "function")
-    else if(mode(FUN) != "function") {
-	farg <- substitute(FUN)
-	if(mode(farg) == "name")
-	    FUN <- get(farg, mode = "function")
-	else stop(paste("\"", farg, "\" is not a function", sep = ""))
-    }
+    FUN <- match.fun(FUN)
+
     answer <- lapply(as.list(X), FUN, ...)
     if(simplify && length(answer) &&
        length(common.len <- unique(unlist(lapply(answer, length)))) == 1) {
