@@ -390,7 +390,7 @@ static void NewExtractNames(SEXP v, SEXP base, SEXP tag, int recurse)
     /* sequence and create the new basename string. */
 
     if (tag != R_NilValue) {
-	base = NewBase(base, tag);
+	PROTECT(base = NewBase(base, tag));
 	savefirstpos = firstpos;
 	saveseqno = seqno;
 	savecount = count;
@@ -464,6 +464,7 @@ static void NewExtractNames(SEXP v, SEXP base, SEXP tag, int recurse)
 	    STRING(ans_names)[firstpos] = base;
 	firstpos = savefirstpos;
 	count = savecount;
+	UNPROTECT(1);
     }
     seqno = seqno + saveseqno;
 }
