@@ -133,7 +133,7 @@ void mem_err_cons()
     error("cons memory (%ld cells) exhausted\n       See \"help(Memory)\" on how to increase the number of cons cells.\n", R_NSize);
 }
 
-#ifdef Macintosh
+#ifdef OLD_Macintosh
 Handle  gStackH;
 Handle  gNHeapH;
 Handle  gVHeapH;
@@ -163,7 +163,7 @@ void InitMemory()
     int i;
 
     gc_reporting = R_Verbose;
-#ifdef Macintosh
+#ifdef OLD_Macintosh
     OSErr   result;
 
     gStackH = TempNewHandle( R_PPStackSize * sizeof(SEXP), &result );
@@ -178,7 +178,7 @@ void InitMemory()
 
     R_PPStackTop = 0;
 
-#ifdef Macintosh
+#ifdef OLD_Macintosh
     gNHeapH = TempNewHandle( R_NSize * sizeof(SEXPREC), &result );
     if( (gNHeapH == NULL) || (result != noErr) )
 	R_Suicide( "couldn't allocate system memory for node heap" );
@@ -191,7 +191,7 @@ void InitMemory()
 
     R_VSize = (((R_VSize + 1)/ sizeof(VECREC)));
 
-#ifdef Macintosh
+#ifdef OLD_Macintosh
     gVHeapH = TempNewHandle( R_VSize * sizeof(VECREC), &result );
     if( (gVHeapH == NULL) || (result != noErr) )
 	R_Suicide( "couldn't allocate system memory for vector heap" );
@@ -420,20 +420,26 @@ SEXP allocList(int n)
 
 void gc(void)
 {
+#ifndef Macintosh
     sigset_t mask, omask;
+#endif
     int vcells, vfrac;
 
     gc_count++;
     if (gc_reporting)
 	REprintf("Garbage collection [nr. %d]...", gc_count);
+#if !defined(Macintosh) && !defined(Win32)
     sigemptyset(&mask);
     sigaddset(&mask,SIGINT);
     sigprocmask(SIG_BLOCK, &mask, &omask);
+#endif
     unmarkPhase();
     markPhase();
     compactPhase();
     scanPhase();
+#if !defined(Macintosh) && !defined(Win32)
     sigprocmask(SIG_SETMASK, &omask, &mask);
+#endif
     if (gc_reporting) {
 	REprintf("\n%ld cons cells free (%ld%%)\n",
 		 R_Collected, (100 * R_Collected / R_NSize));
@@ -445,6 +451,45 @@ void gc(void)
 }
 
 
+SEXP do_memoryprofile(SEXP call, SEXP op, SEXP args, SEXP env)
+{
+    SEXP ans, nms;
+    int i;
+    unmarkPhase();
+    markPhase();
+    PROTECT(ans = allocVector(INTSXP, 21));
+    PROTECT(nms = allocVector(STRSXP, 21));
+    for (i = 0; i < 21; i++) {
+        STRING(ans)[i] = 0;
+        STRING(nms)[i] = R_BlankString;
+    }
+    STRING(nms)[NILSXP]     = mkChar("NILSXP");
+    STRING(nms)[SYMSXP]     = mkChar("SYMSXP");
+    STRING(nms)[LISTSXP]    = mkChar("LISTSXP");
+    STRING(nms)[CLOSXP]     = mkChar("CLOSXP");
+    STRING(nms)[ENVSXP]     = mkChar("ENVSXP");
+    STRING(nms)[PROMSXP]    = mkChar("PROMSXP");
+    STRING(nms)[LANGSXP]    = mkChar("LANGSXP");
+    STRING(nms)[SPECIALSXP] = mkChar("SPECIALSXP");
+    STRING(nms)[BUILTINSXP] = mkChar("BUILTINSXP");
+    STRING(nms)[CHARSXP]    = mkChar("CHARSXP");
+    STRING(nms)[LGLSXP]     = mkChar("LGLSXP");
+    STRING(nms)[INTSXP]     = mkChar("INTSXP");
+    STRING(nms)[REALSXP]    = mkChar("REALSXP");
+    STRING(nms)[CPLXSXP]    = mkChar("CPLXSXP");
+    STRING(nms)[STRSXP]     = mkChar("STRSXP");
+    STRING(nms)[DOTSXP]     = mkChar("DOTSXP");
+    STRING(nms)[ANYSXP]     = mkChar("ANYSXP");
+    STRING(nms)[VECSXP]     = mkChar("VECSXP");
+    STRING(nms)[EXPRSXP]    = mkChar("EXPRSXP");
+    for (i = 0; i < R_NSize; i++)
+	if(MARK(&R_NHeap[i]))
+            INTEGER(ans)[TYPEOF(&R_NHeap[i])] += 1;
+    setAttrib(ans, R_NamesSymbol, nms);
+    UNPROTECT(2);
+    return ans;
+}
+
 /* "unmarkPhase" reset mark in ALL cons cells */
 
 void unmarkPhase(void)
@@ -713,3 +758,26 @@ void C_free(char *p)
     }
     error("C_free(): attempt to free pointer not allocated by C_alloc()\n");
 }
+
+/* S-like wrappers for calloc, realloc and free that check for error
+   conditions */
+
+void *R_chk_calloc(size_t nelem, size_t elsize)
+{
+    void *p;
+    p = calloc(nelem, elsize);
+    if(!p) error("Calloc could not allocate memory");
+    return(p);
+}
+void *R_chk_realloc(void *ptr, size_t size)
+{
+    void *p;
+    p = realloc(ptr, size);
+    if(!p) error("Realloc could not re-allocate memory");
+    return(p);
+}
+void R_chk_free(void *ptr)
+{
+    if(!ptr) warning("attempt to free NULL pointer by Free");
+    free(ptr);
+}
