@@ -227,9 +227,13 @@ void printVector(SEXP x, int index, int quote)
 	}
 }
 
-/* The following code prints vectors which have every element named */
-/* Primitives for each type of vector are presented first, followed */
-/* by the main (despatching) function */
+/* The following code prints vectors which have every element named
+ * Primitives for each type of vector are presented first, followed
+ * by the main (dispatching) function.
+
+ * 1) These functions are almost identical... (use Macro to clarify ?)
+ * 2) S prints a _space_ in the first column for named vectors; we dont.
+ */
 
 static void printNamedLogicalVector(int * x, int n, SEXP * names)
 {
@@ -237,7 +241,6 @@ static void printNamedLogicalVector(int * x, int n, SEXP * names)
 
     formatLogical(x, n, &w);
     formatString(names, n, &wn, 0);
-
     if (w < wn) w = wn;
     nperline = PRINT_WIDTH / (w + PRINT_GAP);
     if (nperline <= 0) nperline = 1;
@@ -251,9 +254,8 @@ static void printNamedLogicalVector(int * x, int n, SEXP * names)
 		    PRINT_GAP, "");
 	}
 	Rprintf("\n");
-	for (j = 0; j < nperline && (k = i * nperline + j) < n; j++) {
+	for (j = 0; j < nperline && (k = i * nperline + j) < n; j++)
 	    Rprintf("%s%*s", EncodeLogical(x[k], w), PRINT_GAP, "");
-	}
     }
     Rprintf("\n");
 }
@@ -298,7 +300,8 @@ static void printNamedRealVector(double * x, int n, SEXP * names)
     for (i = 0; i < nlines; i++) {
 	if (i) Rprintf("\n");
 	for (j = 0; j < nperline && (k = i * nperline + j) < n; j++) {
-	    Rprintf("%s%*s", EncodeString(CHAR(names[k]), w, 0, adj_right), PRINT_GAP, "");
+	    Rprintf("%s%*s", EncodeString(CHAR(names[k]), w, 0, adj_right),
+		    PRINT_GAP, "");
 	}
 	Rprintf("\n");
 	for (j = 0; j < nperline && (k = i * nperline + j) < n; j++)
@@ -323,15 +326,17 @@ static void printNamedComplexVector(complex *x, int n, SEXP *names)
     for (i = 0; i < nlines; i++) {
 	if (i) Rprintf("\n");
 	for (j = 0; j < nperline && (k = i * nperline + j) < n; j++) {
-	    Rprintf("%s%*s", EncodeString(CHAR(names[k]), w, 0, adj_right), PRINT_GAP, "");
+	    Rprintf("%s%*s", EncodeString(CHAR(names[k]), w, 0, adj_right),
+		    PRINT_GAP, "");
 	}
 	Rprintf("\n");
 	for (j=0; j<nperline && (k =i*nperline+j) < n; j++) {
+	    if(j) Rprintf("%*s", PRINT_GAP, "");
 	    if (ISNA(x[j].r) || ISNA(x[j].i)) {
 		Rprintf("%s", EncodeReal(NA_REAL, w, 0, 0));
 	    }
 	    else {
-		Rprintf("%*s%s", PRINT_GAP, "", EncodeReal(x[k].r, wr, dr, er));
+		Rprintf("%s", EncodeReal(x[k].r, wr, dr, er));
 #ifdef IEEE_754
 		if(ISNAN(x[k].i))
 		    Rprintf("+%si", "NaN");
@@ -351,7 +356,6 @@ static void printNamedStringVector(SEXP * x, int n, int quote, SEXP * names)
 {
     int i, j, k, w, wn, nlines, nperline;
 
-
     formatString(x, n, &w, quote);
     formatString(names, n, &wn, 0);
     if (w < wn) w = wn;
@@ -363,11 +367,13 @@ static void printNamedStringVector(SEXP * x, int n, int quote, SEXP * names)
     for (i = 0; i < nlines; i++) {
 	if (i) Rprintf("\n");
 	for (j = 0; j < nperline && (k = i * nperline + j) < n; j++) {
-	    Rprintf("%s%*s", EncodeString(CHAR(names[k]), w, 0, adj_right), PRINT_GAP, "");
+	    Rprintf("%s%*s", EncodeString(CHAR(names[k]), w, 0, adj_right),
+		    PRINT_GAP, "");
 	}
 	Rprintf("\n");
 	for (j = 0; j < nperline && (k = i * nperline + j) < n; j++)
-	    Rprintf("%s%*s", EncodeString(CHAR(x[k]), w, quote, adj_right), PRINT_GAP, "");
+	    Rprintf("%s%*s", EncodeString(CHAR(x[k]), w, quote, adj_right),
+		    PRINT_GAP, "");
     }
     Rprintf("\n");
 }
