@@ -480,7 +480,7 @@ unsigned int GetX11Pixel(int r, int g, int b)
 static void FreeX11Colors()
 {
     int i;
-    if (model == PSEUDOCOLOR2 && Vclass == PseudoColor) {
+    if (model == PSEUDOCOLOR2) {
 	for (i = 0; i < PaletteSize; i++)
 	    XFreeColors(display, colormap, &(XPalette[i].pixel), 1, 0);
 	PaletteSize = 0;
@@ -539,8 +539,6 @@ static int SetupX11Color()
 	printf("Unknown Visual\n");
 	return 0;
     }
-    whitepixel = GetX11Pixel(255, 255, 255);
-    blackpixel = GetX11Pixel(0, 0, 0);
     return 1;
 }
 
@@ -912,6 +910,8 @@ static int X11_Open(DevDesc *dd, x11Desc *xd, char *dsp,
 	devPtrContext = XUniqueContext();
 	displayOpen = 1;
     }
+    whitepixel = GetX11Pixel(255, 255, 255);
+    blackpixel = GetX11Pixel(0, 0, 0);
 
     if (!SetBaseFont(xd)) {
 	Rprintf("can't find X11 font\n");
@@ -1118,7 +1118,7 @@ static void X11_NewPage(DevDesc *dd)
     x11Desc *xd = (x11Desc *) dd->deviceSpecific;
 
     FreeX11Colors();
-    if(xd->bg != dd->dp.bg) {
+    if((model == PSEUDOCOLOR2) || (xd->bg != dd->dp.bg)) {
 	xd->bg = dd->dp.bg;
 	whitepixel = GetX11Pixel(R_RED(xd->bg),R_GREEN(xd->bg),R_BLUE(xd->bg));
 	XSetWindowBackground(display, xd->window, whitepixel);
